plugin_paths = { "/usr/share/jitsi-meet/prosody-plugins/" }

-- domain mapper options, must at least have domain base set to use the mapper
muc_mapper_domain_base = "vr.binaural.me";

external_service_secret = "XKYKzG8JTBYIdsCO";
external_services = {
     { type = "stun", host = "vr.binaural.me", port = 3478 },
     { type = "turn", host = "vr.binaural.me", port = 3478, transport = "udp", secret = true, ttl = 86400, algorithm = "turn" },
     { type = "turns", host = "vr.binaural.me", port = 5349, transport = "tcp", secret = true, ttl = 86400, algorithm = "turn" }
};

cross_domain_bosh = false;
consider_bosh_secure = true;
cross_domain_websocket = true;
consider_websocket_secure = true;
-- https_ports = { }; -- Remove this line to prevent listening on port 5284

-- https://ssl-config.mozilla.org/#server=haproxy&version=2.1&config=intermediate&openssl=1.1.0g&guideline=5.4
ssl = {
    protocol = "tlsv1_2+";
    ciphers = "ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:DHE-RSA-AES128-GCM-SHA256:DHE-RSA-AES256-GCM-SHA384"
}

unlimited_jids = {
    "focus@auth.vr.binaural.me",
    "jvb@auth.vr.binaural.me"
}

VirtualHost "vr.binaural.me"
    -- enabled = false -- Remove this line to enable this host
    authentication = "anonymous"
    -- Properties below are modified by jitsi-meet-tokens package config
    -- and authentication above is switched to "token"
    --app_id="example_app_id"
    --app_secret="example_app_secret"
    -- Assign this host a certificate for TLS, otherwise it would use the one
    -- set in the global section (if any).
    -- Note that old-style SSL on port 5223 only supports one certificate, and will always
    -- use the global one.
    ssl = {
        key = "/etc/prosody/certs/vr.binaural.me.key";
        certificate = "/etc/prosody/certs/vr.binaural.me.crt";
    }
    av_moderation_component = "avmoderation.vr.binaural.me"
    speakerstats_component = "speakerstats.vr.binaural.me"
    conference_duration_component = "conferenceduration.vr.binaural.me"
    -- we need bosh
    modules_enabled = {
        "websocket";
	    "smacks";
        "bosh";
        "pubsub";
        "ping"; -- Enable mod_ping
        "speakerstats";
        "external_services";
        "conference_duration";
        "muc_lobby_rooms";
        "av_moderation";
    }
    c2s_require_encryption = false
    lobby_muc = "lobby.vr.binaural.me"
    main_muc = "conference.vr.binaural.me"
    -- muc_lobby_whitelist = { "recorder.vr.binaural.me" } -- Here we can whitelist jibri to enter lobby enabled rooms

    -- smacks options
        smacks_hibernation_time = 5;
	    smacks_max_unacked_stanzas = 20;
        smacks_max_hibernated_sessions = 10;
        smacks_max_old_sessions = 10;



Component "conference.vr.binaural.me" "muc"
    restrict_room_creation = true
    storage = "memory"
    modules_enabled = {
        "muc_meeting_id";
        "muc_domain_mapper";
        "polls";
        --"token_verification";
    }
    admins = { "focus@auth.vr.binaural.me" }
    muc_room_locking = false
    muc_room_default_public_jids = true

-- internal muc component
Component "internal.auth.vr.binaural.me" "muc"
    storage = "memory"
    modules_enabled = {
        "ping";
    }
    admins = { "focus@auth.vr.binaural.me", "jvb@auth.vr.binaural.me" }
    muc_room_locking = false
    muc_room_default_public_jids = true

VirtualHost "auth.vr.binaural.me"
    ssl = {
        key = "/etc/prosody/certs/auth.vr.binaural.me.key";
        certificate = "/etc/prosody/certs/auth.vr.binaural.me.crt";
    }
    modules_enabled = {
        "limits_exception";
    }
    authentication = "internal_hashed"

-- Proxy to jicofo's user JID, so that it doesn't have to register as a component.
Component "focus.vr.binaural.me" "client_proxy"
    target_address = "focus@auth.vr.binaural.me"

Component "speakerstats.vr.binaural.me" "speakerstats_component"
    muc_component = "conference.vr.binaural.me"

Component "conferenceduration.vr.binaural.me" "conference_duration_component"
    muc_component = "conference.vr.binaural.me"

Component "avmoderation.vr.binaural.me" "av_moderation_component"
    muc_component = "conference.vr.binaural.me"

Component "lobby.vr.binaural.me" "muc"
    storage = "memory"
    restrict_room_creation = true
    muc_room_locking = false
    muc_room_default_public_jids = true
